import React, { FC, useContext } from 'react';
import axios from 'axios';
import { NonAuthRoutes } from 'api/routes';
import { useHistory } from 'react-router-dom';
import {
  Grid,
  Typography,
  TextField,
  Button,
  Select,
  MenuItem,
  FormControl,
} from '@material-ui/core';
import { Header } from 'components/Utils/Header';
import { profilePageStyle } from './ProfilePage.style';

export const ProfilePage: FC = () => {
  const history = useHistory();
  const logout = (): void => {
    axios.get('/api/web/login/logout').then(() => {
      history.replace(NonAuthRoutes.home);
    });
  };

  const classes = profilePageStyle();

  const [lang, setLang] = React.useState<string | number>('');
  const [open, setOpen] = React.useState(false);

  const handleChange = (event: React.ChangeEvent<{ value: unknown }>): void => {
    setLang(event.target.value as number);
  };

  const handleClose = (): void => {
    setOpen(false);
  };

  const handleOpen = (): void => {
    setOpen(true);
  };

  return (
    <div data-testid="ProfilePage">
      <Header title="Setup" subtitle="your profile" />
      <FormControl aria-label="Info User">
        <Grid item container>
          <Grid item xs={2} />
          <Grid item container xs={8}>
            <Grid item xs={5} className={classes.paddingTopLittle}>
              <TextField
                autoFocus
                margin="dense"
                id="firstName"
                label="First Name"
                type="text"
                fullWidth
              />
            </Grid>
            <Grid item xs={2} className={classes.paddingTopLittle} />
            <Grid item xs={5} className={classes.paddingTopLittle}>
              <TextField
                autoFocus
                margin="dense"
                id="lastName"
                label="Last Name"
                type="text"
                fullWidth
              />
            </Grid>

            <Grid item xs={5} className={classes.paddingTopLittle}>
              <TextField
                autoFocus
                margin="dense"
                id="address"
                label="Address"
                type="text"
                fullWidth
              />
            </Grid>

            <Grid item xs={2} className={classes.paddingTopLittle} />

            <Grid item xs={2} className={classes.paddingTopLittle}>
              <TextField
                autoFocus
                margin="dense"
                id="cap"
                label="CAP"
                type="text"
                fullWidth
              />
            </Grid>

            <Grid item xs={1} className={classes.paddingTopLittle} />

            <Grid item xs={2} className={classes.paddingTopLittle}>
              <TextField
                autoFocus
                margin="dense"
                id="province"
                label="Prov"
                type="text"
                fullWidth
              />
            </Grid>

            <Grid item xs={12} className={classes.paddingTopLittle}>
              <TextField
                autoFocus
                margin="dense"
                id="email"
                label="Email"
                type="text"
                fullWidth
              />
            </Grid>

            <Grid item xs={12} className={classes.paddingTopLittle}>
              <TextField
                autoFocus
                margin="dense"
                id="cardNumber"
                label="Card No"
                type="text"
                fullWidth
              />
            </Grid>

            <Grid item xs={12} className={classes.paddingTop}>
              <Select
                labelId="Language"
                id="Language"
                label="Language"
                open={open}
                onClose={handleClose}
                onOpen={handleOpen}
                value={lang}
                onChange={handleChange}
                fullWidth
              >
                <MenuItem value={20}>Italiano</MenuItem>
                <MenuItem value={10}>English</MenuItem>
                <MenuItem value={30}>Deutsch</MenuItem>
                <MenuItem value={40}>Ladinisch</MenuItem>
              </Select>
            </Grid>

            <Button
              color="primary"
              variant="contained"
              className={classes.buttonUpdate}
            >
              Update
            </Button>

            <Button
              fullWidth
              variant="outlined"
              color="default"
              onClick={logout}
              className={classes.marginTop}
            >
              Logout
            </Button>
          </Grid>

          <Grid item xs={2} />
        </Grid>
      </FormControl>
    </div>
  );
};
